@@ -14,16 +14,16 @@ use notation_midi::prelude::{
     MidiPlugin,
 };
 
-use super::state::{NotationState, TabPathes};
-
 pub struct NotationPlugins;
 impl PluginGroup for NotationPlugins {
     fn build(&mut self, group: &mut PluginGroupBuilder) {
-        group.add(FontPlugin);
+        group.add(EguiPlugin);
         group.add(EntryPlugin);
         group.add(MelodyPlugin);
         group.add(LyricsPlugin);
         group.add(BarPlugin);
+        group.add(MelodyPlugin);
+        group.add(HarmonyPlugin);
         group.add(StringsPlugin);
         group.add(ShapesPlugin);
         group.add(MiniPlugin);
@@ -45,14 +45,16 @@ pub struct NotationApp;
 impl NotationApp {
     pub const TITLE: &'static str = "Fun Notation";
 
-    pub fn new_app<A: ExtraAssets>(title: &str) -> App {
+    pub fn new_app<A: ExtraAssets>(args: NotationArgs, title: &str) -> App {
         let mut app = App::new();
+        app.insert_resource(args);
         AssetLoader::new(NotationAssetsStates::Loading)
             .continue_to_state(NotationAssetsStates::Loaded)
             .with_collection::<NotationAssets>()
             .with_collection::<A>()
             .build(&mut app);
-        app.add_state(NotationAssetsStates::Loading);
+        app.add_state(NotationAssetsStates::Loading)
+            .add_startup_system(NotationAssets::setup_keys::<A>);
         Self::insert_window_descriptor(&mut app, String::from(title));
         super::events::add_notation_app_events(&mut app);
 
@@ -83,30 +85,16 @@ impl NotationApp {
         #[cfg(feature = "dev")]
         app.add_plugins(crate::dev::NotationDevPlugins);
 
-        #[cfg(feature = "inspector")]
-        app.add_plugins(crate::inspector::NotationInspectorPlugins);
-
         app
     }
 
-    #[cfg(target_arch = "wasm32")]
-    pub fn get_tab_from_url() -> Result<String, String> {
-        web_sys::window()
-            .ok_or("No_Window".to_owned())
-            .and_then(|x| x.document().ok_or("No_Document".to_owned()))
-            .and_then(|x| x.location().ok_or("No_Location".to_owned()))
-            .and_then(|x| x.search().map_err(|e| format!("No_Search:{:?}", e)))
-            .map(|x| x.trim_start_matches('?').to_owned())
-    }
-
-    pub fn run_with_extra<A, F>(tab_pathes: Vec<String>, extra: F)
+    pub fn run_with_extra<A, F>(args: NotationArgs, extra: F)
     where
         A: ExtraAssets,
         F: Fn(&mut App),
     {
-        let mut app = NotationApp::new_app::<A>(Self::TITLE);
+        let mut app = NotationApp::new_app::<A>(args, Self::TITLE);
 
-        app.insert_resource(TabPathes(tab_pathes));
         app.init_resource::<NotationState>();
 
         app.add_startup_system(Self::setup_camera);
@@ -117,6 +105,7 @@ impl NotationApp {
         app.add_system_set(
             SystemSet::on_enter(NotationAssetsStates::Loaded)
                 .with_system(NotationAssets::add_extra_assets::<A>)
+                .with_system(crate::egui::egui_fonts::setup_egui_fonts::<A>)
                 .with_system(Self::setup_window_size),
         );
         app.add_system_set(
@@ -134,8 +123,8 @@ impl NotationApp {
         extra(&mut app);
         app.run();
     }
-    pub fn run<A: ExtraAssets>(tab_pathes: Vec<String>) {
-        Self::run_with_extra::<A, _>(tab_pathes, |_app|{})
+    pub fn run<A: ExtraAssets>(args: NotationArgs) {
+        Self::run_with_extra::<A, _>(args, |_app|{})
     }
 }
 
@@ -214,12 +203,13 @@ impl NotationApp {
             }
         }
     }
-    pub fn load_tab<F: Fn(String) -> Option<ProtoTab>>(
+    pub fn load_tab<F: Fn(String) -> Option<TabAsset>>(
         commands: &mut Commands,
         time: &Time,
         windows: &mut Windows,
         state: &mut NotationState,
         theme: &mut NotationTheme,
+        settings: &NotationSettings,
         evts: &mut EventWriter<AddTabEvent>,
         entities_query: &Query<Entity, With<GlobalTransform>>,
         viewer_query: &Query<(Entity, &TabViewer), With<TabViewer>>,
@@ -228,7 +218,7 @@ impl NotationApp {
         if state.window_width > 0.0
             && state.window_height > 0.0
             && state.tab.is_none()
-            && state.parse_error.is_none()
+            && state.tab_error.is_none()
         {
             let mut count = 0;
             for _ in entities_query.iter() {
@@ -271,20 +261,29 @@ impl NotationApp {
                 return;
             }
             println!("\nload_tab(): Loading: {}", state.tab_path);
-            if let Some(tab) = load_tab(state.tab_path.clone()) {
-                match Tab::try_parse_arc(tab) {
-                    Ok(tab) => {
-                        state.tab = Some(tab.clone());
-                        if let Some(window) = windows.get_primary_mut() {
-                            let title = format!("{} - {}", NotationApp::TITLE, state.tab_path);
-                            window.set_title(title);
-                        }
-                        theme._bypass_systems = false;
-                        evts.send(AddTabEvent(tab));
-                    }
-                    Err(err) => {
-                        println!("nload_tab(): Parse Tab Failed: {:?}", err);
-                        state.parse_error = Some(err);
+            if state.tab_error.is_none() {
+                if let Some(tab_asset) = load_tab(state.tab_path.clone()) {
+                    match tab_asset.tab {
+                        Ok(tab) => {
+                            match Tab::try_parse_arc(tab, settings.add_ready_section, state.bars_range) {
+                                Ok(tab) => {
+                                    state.tab = Some(tab.clone());
+                                    if let Some(window) = windows.get_primary_mut() {
+                                        let title = format!("{} - {}", NotationApp::TITLE, state.tab_path);
+                                        window.set_title(title);
+                                    }
+                                    theme._bypass_systems = false;
+                                    evts.send(AddTabEvent(tab));
+                                }
+                                Err(err) => {
+                                    println!("nload_tab(): Parse Tab Failed: {:?}", err);
+                                    state.tab_error = Some(TabError::ParseFailed(err));
+                                }
+                            }
+                        },
+                        Err(err) => {
+                            state.tab_error = Some(err);
+                        },
                     }
                 }
             }
@@ -294,10 +293,10 @@ impl NotationApp {
         asset_server: &AssetServer,
         assets: &Assets<TabAsset>,
         tab_path: String,
-    ) -> Option<ProtoTab> {
+    ) -> Option<TabAsset> {
         let tab_asset: Handle<TabAsset> = asset_server.load(tab_path.as_str());
         if let Some(asset) = assets.get(&tab_asset) {
-            Some(asset.tab.clone())
+            Some(asset.clone())
         } else {
             None
         }
